Get EMA catch table
get_ema_catch.RdThis function pulls ecosystem survey data (from EMA surveys) from the AKFIN data server It includes parameters to control start and end year, gear type, and TSN (species code)
get_ema_catch.RdThis function pulls ecosystem survey data (from EMA surveys) from the AKFIN data server It includes parameters to control start and end year, gear type, and TSN (species code)